galvani
=======

Read proprietary file formats from electrochemical test stations

## Bio-Logic .mpr files ##

Use the `MPRfile` class from BioLogic.py (exported in the main package)

## Arbin .res files ##

Use the res2sqlite.py script to convert the .res file to a sqlite3 database
with the same schema.
